@@ -40,6 +40,9 @@ class BaseField(object):
     def to_son(self, value):
         return value
 
+    def to_query(self, value):
+        return self.to_son(value)
+
     def from_son(self, value):
         return value
 
